@@ -1,20 +1,22 @@
 name = "version"
-__version__ = "0.2.7"
+__version__ = "0.2.20"
 
 __requirements__ = [
     "pydantic",
     "requests",
-    "pydantic",
     "numpy",
     "torch",
     "sentence-transformers",
     "fastapi",
     "uvicorn",
     "PyYaml",
-    "openai",
+    "openai>=1.0",
     "tiktoken",
     "google-auth",
     "google-cloud-aiplatform",
-    "fastapi",
-    "boto3",
+    "langchain",
+    "anthropic>=0.3.0",
+    "python-dotenv",
+    "cohere",
+    "tokenizer",
 ]
